==> zio-aws-apigatewayv2_2.13-5.17.104.7-sources.jar: zio/aws/apigatewayv2/model/GetIntegrationResponsesResponse.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetIntegrationResponsesResponse(
    items: Option[Iterable[zio.aws.apigatewayv2.model.IntegrationResponse]] =
      None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponsesResponse = {
    import GetIntegrationResponsesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponsesResponse
      .builder()
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.apigatewayv2.model.GetIntegrationResponsesResponse.ReadOnly =
    zio.aws.apigatewayv2.model.GetIntegrationResponsesResponse
      .wrap(buildAwsValue())
}
object GetIntegrationResponsesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponsesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetIntegrationResponsesResponse =
      zio.aws.apigatewayv2.model.GetIntegrationResponsesResponse(
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def items
        : Option[List[zio.aws.apigatewayv2.model.IntegrationResponse.ReadOnly]]
    def nextToken: Option[NextToken]
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.apigatewayv2.model.IntegrationResponse.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponsesResponse
  ) extends zio.aws.apigatewayv2.model.GetIntegrationResponsesResponse.ReadOnly {
    override val items: Option[
      List[zio.aws.apigatewayv2.model.IntegrationResponse.ReadOnly]
    ] = scala
      .Option(impl.items())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.apigatewayv2.model.IntegrationResponse.wrap(item)
        }.toList
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.apigatewayv2.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponsesResponse
  ): zio.aws.apigatewayv2.model.GetIntegrationResponsesResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-apigatewayv2_2.13-6.20.97.2-sources.jar: zio/aws/apigatewayv2/model/GetIntegrationResponsesResponse.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetIntegrationResponsesResponse(
    items: Optional[Iterable[zio.aws.apigatewayv2.model.IntegrationResponse]] =
      Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponsesResponse = {
    import GetIntegrationResponsesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponsesResponse
      .builder()
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.apigatewayv2.model.GetIntegrationResponsesResponse.ReadOnly =
    zio.aws.apigatewayv2.model.GetIntegrationResponsesResponse
      .wrap(buildAwsValue())
}
object GetIntegrationResponsesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponsesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetIntegrationResponsesResponse =
      zio.aws.apigatewayv2.model.GetIntegrationResponsesResponse(
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def items: Optional[
      List[zio.aws.apigatewayv2.model.IntegrationResponse.ReadOnly]
    ]
    def nextToken: Optional[NextToken]
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.apigatewayv2.model.IntegrationResponse.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponsesResponse
  ) extends zio.aws.apigatewayv2.model.GetIntegrationResponsesResponse.ReadOnly {
    override val items: Optional[
      List[zio.aws.apigatewayv2.model.IntegrationResponse.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.items())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.apigatewayv2.model.IntegrationResponse.wrap(item)
        }.toList
      )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.apigatewayv2.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponsesResponse
  ): zio.aws.apigatewayv2.model.GetIntegrationResponsesResponse.ReadOnly =
    new Wrapper(impl)
}
